==> haskell-th-env-0.1.1-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-1OY0OLxQnjhEASyIYVexz3
key:                  th-env-0.1.1-1OY0OLxQnjhEASyIYVexz3
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  3828d2df8f7e387d272230d82c361d3e
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-1OY0OLxQnjhEASyIYVexz3
depends:
    base-4.17.2.1 template-haskell-2.19.0.0
    th-compat-0.1.6-GaFLKVM8yafAG7gvZ9TvNJ

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-env-0.1.1-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-8bkdfXQBoD7ACPeK9nLIrj
key:                  th-env-0.1.1-8bkdfXQBoD7ACPeK9nLIrj
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  d23612bd0551896323c500d01581fa11
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-8bkdfXQBoD7ACPeK9nLIrj
depends:
    base-4.17.2.1 template-haskell-2.19.0.0
    th-compat-0.1.6-8A3EBv8benAptJJGDODcK

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
